/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Googlebar for Mozilla.
 *
 * The Initial Developer of the Original Code is Andy Edmonds.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Andy Boughton
 *  Andrew Houghton
 *  John Woods
 *  Bernd Kuemmerlen
 *  Robert Mulcahy
 *  Alfred Kayser
 *  Reflex
 *  Gary Turnbull
 *  Raj Bhaskar
 *  Joachim Thewes
 *  Henrik Gemal
 *  Robert Fernandes
 *  Joe Chellman
 *  Franki Cheung
 *  Alban Fonrouge
 *  Martin Hassman
 *  Ufuk Kayserilioglu
 *  Yoni Gilad
 *  Tim Schmidt
 *  timeless
 *  Francis Turner
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var myGooglebarHistory = {

	addToHistory: function(aTerm, aIgnorePref) {
	    // This function adds the string "term" to the search
	    // history *only* if it is not already there
		
		// If ther term already happens to be in the search
		// history then we will move it to the top of the list
	
	    var critBox = myGooglebarUtil.getElement("ggb_search_criteria");
	    var historyMenu = critBox.childNodes.item(0);
	    var numHistItems = historyMenu.childNodes.length;
	    var alreadyInHist = null;
	    var i = 0;
	
	    // iterate over the current history and check if the term is
	    // already there
	    for (i = 0; i < numHistItems; i++) {
	        if (aTerm == historyMenu.childNodes[i].getAttribute("label")) {
	            alreadyInHist = historyMenu.childNodes[i];
	        }
	    }
	
	    // add to history
	    if (!alreadyInHist) {
	        var myMenuItem = document.createElement("menuitem");
	        myMenuItem.setAttribute("label", aTerm);
	        myMenuItem.setAttribute("tooltiptext", aTerm);
	        myMenuItem.setAttribute("oncommand", "myGooglebar.autoSearch(event);");
	
	        if (numHistItems <= 0) {
	            historyMenu.appendChild(myMenuItem);
	        }
	        else {
	            historyMenu.insertBefore(myMenuItem, historyMenu.childNodes[0]);
	        }
	
	        if (!aIgnorePref) {
	            this.addToHistoryPref(aTerm);
	        }
	
			this.trimHistory();
	    }
	    else {
	    	historyMenu.removeChild(alreadyInHist);
	    	historyMenu.insertBefore(alreadyInHist, historyMenu.childNodes[0]);
	    }
	},
	
	addToHistoryPref: function(aTerm) {
	    // This function adds the string "term" to the search
	    // history preference *only* if the option to save
	    // search history is selected.
	    //
	    // This function should only be called after it has
	    // been established that this item is not already
	    // in the list of items (see addToHistory)
	    // otherwise there may be duplicate items added to
	    // the history.  There could be a check to see whether
	    // it exists here as well to prevent this problem
	    // but it doesn't appear to be necessary at this point
	    // since this function is only called from within the
	    // addToHistory function.
	    //
	    // Another potential problem that should be addressed
	    // is to check whether or not the || delimeter is
	    // contained in the search term, if it is then it will
	    // cause a problem when the history is reloaded.
	
	    if (myGooglebarPrefUtil.getPrefValue(GB_PREF_HISTORY_SAVE_NAME)) {
	        if (!aTerm) {
	            return;
	        }
	
			var historyArray = myGooglebarPrefUtil.getPrefValue(GB_PREF_HISTORY_TERMS_NAME);
			historyArray[historyArray.length] = aTerm;
			myGooglebarPrefUtil.setPrefValue(GB_PREF_HISTORY_TERMS_NAME, historyArray);
	    }
	},
	
	clearHistory: function(aFlag) {
		// introduced a parm to indicate whether to clear the critBox and search buttons
		// true when called by user, false when used otherwise.
		
	    // This function removes all items from the search
	    // history (both history pref and popup menu)
	    var critBox = myGooglebarUtil.getElement("ggb_search_criteria");
	
	    if (!critBox) {
			alert(myGooglebarUtil.getProperty("gb.googlebarClearHistory.1"));
			return;
		}
	
		var saveCurrCrit = critBox.value;
	    var historyMenu = critBox.childNodes.item(0);
	    var numHistItems = historyMenu.childNodes.length;
	
	
	    // iterate over the current history and remove each item
	    for (var i = numHistItems - 1; i >= 0; i--) {
	        historyMenu.removeChild(historyMenu.childNodes[i]);
	    }
	
	    // next clear all the term buttons, the input field
	    // (by setting selected index to -1), and history pref
	    myGooglebar.clearTerms();
	    critBox.selectedIndex = -1;
	    myGooglebarPrefUtil.setPrefValue(GB_PREF_HISTORY_TERMS_NAME, new Array(0));
	    
	    // When the history is cleared all highlighting must be removed
	    myGooglebarHighlight.checkHighlight("");
	
		// some people want this cleared, bug 6430, 6462
	    // so... when invoked by user actions, we don't restore it
	    // only invoked in the main pulldown menu at present.
		if (!aFlag) {
		    if (saveCurrCrit) {
		    	critBox.value = saveCurrCrit;
		   	}
			myGooglebar.addTerms(saveCurrCrit);
		}
	},
	
	initialize: function() {
		var historyArray = myGooglebarPrefUtil.getPrefValue(GB_PREF_HISTORY_TERMS_NAME);
	
	    // iterate over the saved history items and add them to the list
	    // and make sure to use the second paramenter of the addToHistory
	    // function so that we don't add it to the saved preference again
	    for (var i = 0; i < historyArray.length; i++) {
	        if (historyArray[i]) {
	            this.addToHistory(historyArray[i], true);
	        }
	    }
	},
	
	refreshHistoryPref: function() {
	    var critBox = myGooglebarUtil.getElement("ggb_search_criteria");
	    var historyMenu = critBox.childNodes.item(0);
	    var numHistItems = historyMenu.childNodes.length;
	
	    // sync up the history preference with the new list
	    var historyArray = new Array(numHistItems);
	
	    for (i = numHistItems - 1; i >= 0; i--) {
	        historyArray[i] = historyMenu.childNodes[i].getAttribute("label");
	    }
	    
	    myGooglebarPrefUtil.setPrefValue(GB_PREF_HISTORY_TERMS_NAME, historyArray);
	},
	
	trimHistory: function() {
		var critBox = myGooglebarUtil.getElement("ggb_search_criteria");
	    var historyMenu = critBox.childNodes.item(0);
	    var numHistItems = historyMenu.childNodes.length;
	    var maxHistItems = myGooglebarPrefUtil.getPrefValue(GB_PREF_HISTORY_MAX_NAME);
	
        // if too many items have been added then remove extra items from the bottom
        if (numHistItems > maxHistItems) {
            var numToRemove = numHistItems - maxHistItems;

            // iterate over the current history and remove any extraneous items
            for (i = 0; i < numToRemove; i++) {
                historyMenu.removeChild(historyMenu.lastChild);
            }
            this.refreshHistoryPref();
        }
	}
};
